@@ -75,6 +75,7 @@ Usage::
         DescribeSpotInstanceRequestsPaginator,
         DescribeSpotPriceHistoryPaginator,
         DescribeStaleSecurityGroupsPaginator,
+        DescribeStoreImageTasksPaginator,
         DescribeSubnetsPaginator,
         DescribeTagsPaginator,
         DescribeTrafficMirrorFiltersPaginator,
@@ -247,6 +248,7 @@ Usage::
     describe_spot_instance_requests_paginator: DescribeSpotInstanceRequestsPaginator = client.get_paginator("describe_spot_instance_requests")
     describe_spot_price_history_paginator: DescribeSpotPriceHistoryPaginator = client.get_paginator("describe_spot_price_history")
     describe_stale_security_groups_paginator: DescribeStaleSecurityGroupsPaginator = client.get_paginator("describe_stale_security_groups")
+    describe_store_image_tasks_paginator: DescribeStoreImageTasksPaginator = client.get_paginator("describe_store_image_tasks")
     describe_subnets_paginator: DescribeSubnetsPaginator = client.get_paginator("describe_subnets")
     describe_tags_paginator: DescribeTagsPaginator = client.get_paginator("describe_tags")
     describe_traffic_mirror_filters_paginator: DescribeTrafficMirrorFiltersPaginator = client.get_paginator("describe_traffic_mirror_filters")
@@ -350,6 +352,7 @@ from mypy_boto3_ec2.paginator import (
     DescribeSpotInstanceRequestsPaginator,
     DescribeSpotPriceHistoryPaginator,
     DescribeStaleSecurityGroupsPaginator,
+    DescribeStoreImageTasksPaginator,
     DescribeSubnetsPaginator,
     DescribeTagsPaginator,
     DescribeTrafficMirrorFiltersPaginator,
@@ -499,6 +502,7 @@ __all__ = (
     "DescribeSpotInstanceRequestsPaginator",
     "DescribeSpotPriceHistoryPaginator",
     "DescribeStaleSecurityGroupsPaginator",
+    "DescribeStoreImageTasksPaginator",
     "DescribeSubnetsPaginator",
     "DescribeTagsPaginator",
     "DescribeTrafficMirrorFiltersPaginator",
